@@ -1,4 +1,4 @@
-#include "Rstaff.h"
+#include "Rstuff.h"
 
 #include "FilteredMatrix.h"
 #include "Logger.h"
@@ -286,16 +286,16 @@ extern "C" {
 		unsigned long cachesizeMb = (unsigned long) INTEGER(cacheMb)[0];
 		bool readonly = LOGICAL(ReadOnly)[0];
 		string filename = CHAR(STRING_ELT(fname,0));
-		if (cachesizeMb<0) {
-			error_R("negative cache size\n");
-			return R_NilValue;
-		}
+//		if (cachesizeMb<0) {
+//			error_R("negative cache size\n");
+//			return R_NilValue;
+//		}
 
 		AbstractMatrix* p = NULL;
 
 		try {
 			p = new FileVector(filename,cachesizeMb,readonly);
-			cout << "open_FileMatrix_R, ptr = " << (void*)p << endl;
+			//cout << "open_FileMatrix_R, ptr = " << (void*)p << endl;
 		} catch (int errcode) {
 			return R_NilValue;
 		}
@@ -362,7 +362,8 @@ extern "C" {
 			return R_NilValue;
 		}
 
-		if (nvariable <0 || nvariable >= nvars) {
+		if (nvariable >= nvars) {
+//		if (nvariable <0 || nvariable >= nvars) {
 			error_R("nvar (%lu) out of range!\n",nvariable);
 			return R_NilValue;
 		}
@@ -601,8 +602,10 @@ extern "C" {
 	}
 
 	SEXP checkNumBits(){
-	    if (sizeof(unsigned long) != 8) {
-    		errorLog << "YOU APPEAR TO WORK ON 32-BIT SYSTEM. LARGE FILES ARE NOT SUPPORTED."<<endl;
+	    if (sizeof(void*) != 8) {
+    		errorLog << 
+		  "YOU APPEAR TO WORK ON A 32-BIT SYSTEM. " << 
+		  "LARGE FILES ARE NOT SUPPORTED." << endl;
     	}
 	    return R_NilValue;
 	}
@@ -612,7 +615,7 @@ extern "C" {
 	*             1 -- copy values from @ptr to @values...
 	*/
 	SEXP assignDoubleMatrix(SEXP ptr, SEXP obsIndexes, SEXP varIndexes, SEXP values, SEXP direction){
-		flush(cout);
+		//flush(cout);
 		
 	    unsigned long varNum, obsNum, obsIndexNum, varIndexNum;
 
@@ -621,7 +624,7 @@ extern "C" {
 
 		unsigned long dir = (unsigned long) INTEGER(direction)[0];
 
-        double *currentValues;
+        double *currentValues = 0;
         if (!(coeff < WRITE_SPEED_PROPORTION)) {
             currentValues = new double[p->getNumObservations()];
         }
@@ -680,7 +683,7 @@ extern "C" {
 		PROTECT(ret = allocVector(LGLSXP, 1));
 		LOGICAL(ret)[0] = TRUE;
 		UNPROTECT(1);
-		flush(cout);
+		//flush(cout);
 		return ret;
 	}
 
